<?php

if ( is_multisite() ) :
/**
 * Test 'site_details' functionality.
 *
 * @group ms-site
 * @group multisite
 */
class Tests_Multisite_Site_Details extends WP_UnitTestCase {
	/**
	 * @dataProvider data_whitelisted_options
	 *
	 * @ticket 40063
	 */
	public function test_update_whitelisted_option_deletes_site_details_cache( $whitelisted_option, $temporary_value ) {
		$site = get_site();

		$original_value = $site->$whitelisted_option;
		update_option( $whitelisted_option, $temporary_value );

		$cached_result = wp_cache_get( $site->id, 'site-details' );

		/* Reset to original value. */
		update_option( $whitelisted_option, $original_value );

		$this->assertFalse( $cached_result );
	}

	/**
	 * @dataProvider data_whitelisted_options
	 *
	 * @ticket 40063
	 */
	public function test_update_whitelisted_option_deletes_blog_details_cache( $whitelisted_option, $temporary_value ) {
		$blog_details = get_blog_details();

		$original_value = $blog_details->$whitelisted_option;
		update_option( $whitelisted_option, $temporary_value );

		$cached_result = wp_cache_get( $blog_details->id, 'blog-details' );

		/* Reset to original value. */
		update_option( $whitelisted_option, $original_value );

		$this->assertFalse( $cached_result );
	}

	/**
	 * @dataProvider data_whitelisted_options
	 *
	 * @ticket 40063
	 */
	public function test_update_whitelisted_option_does_not_delete_site_cache( $whitelisted_option, $temporary_value ) {
		$site = get_site();

		$original_value = $site->$whitelisted_option;
		update_option( $whitelisted_option, $temporary_value );

		$cached_result = wp_cache_get( $site->id, 'sites' );

		/* Reset to original value. */
		update_option( $whitelisted_option, $original_value );

		$this->assertNotFalse( $cached_result );
	}

	/**
	 * @dataProvider data_whitelisted_options
	 *
	 * @ticket 40063
	 */
	public function test_update_whitelisted_option_does_not_delete_short_blog_details_cache( $whitelisted_option, $temporary_value ) {
		$blog_details = get_blog_details( null, false );

		$original_value = get_option( $whitelisted_option );
		update_option( $whitelisted_option, $temporary_value );

		$cached_result = wp_cache_get( $blog_details->id . 'short', 'blog-details' );

		/* Reset to original value. */
		update_option( $whitelisted_option, $original_value );

		$this->assertNotFalse( $cached_result );
	}

	/**
	 * @dataProvider data_whitelisted_options
	 *
	 * @ticket 40063
	 */
	public function test_update_whitelisted_option_does_not_update_sites_last_changed( $whitelisted_option, $temporary_value ) {
		$last_changed = wp_cache_get_last_changed( 'sites' );

		$original_value = get_option( $whitelisted_option );
		update_option( $whitelisted_option, $temporary_value );

		$new_last_changed = wp_cache_get_last_changed( 'sites' );

		/* Reset to original value. */
		update_option( $whitelisted_option, $original_value );

		$this->assertSame( $new_last_changed, $last_changed );
	}

	public function data_whitelisted_options() {
		return array(
			array( 'blogname', 'Custom Site' ),
			array( 'home', 'http://custom-site-url.org' ),
			array( 'siteurl', 'http://custom-site-url.org' ),
			array( 'post_count', '4' ),
		);
	}

	/**
	 * @ticket 40063
	 */
	public function test_update_random_blog_option_does_not_delete_cache() {
		$site = get_site();

		update_option( 'foobar_option', 'foobar_value' );
		$cached_result = wp_cache_get( $site->id, 'sites' );

		delete_option( 'foobar_option' );

		$this->assertNotFalse( $cached_result );
	}
}

endif;
